@@ -19,21 +19,22 @@ describe 'magnum::keystone::authtoken' do
         is_expected.to contain_magnum_config('keystone_authtoken/password').with_value('magnum_password')
         is_expected.to contain_magnum_config('keystone_authtoken/auth_url').with_value('http://localhost:5000')
         is_expected.to contain_magnum_config('keystone_authtoken/project_name').with_value('services')
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_user').with_value('magnum')
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_password').with_value('magnum_password')
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_tenant_name').with_value('services')
         is_expected.to contain_magnum_config('keystone_authtoken/user_domain_name').with_value('Default')
         is_expected.to contain_magnum_config('keystone_authtoken/project_domain_name').with_value('Default')
+        is_expected.to contain_magnum_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/auth_type').with_value('password')
         is_expected.to contain_magnum_config('keystone_authtoken/www_authenticate_uri').with_value('http://localhost:5000')
         is_expected.to contain_magnum_config('keystone_authtoken/auth_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_magnum_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_magnum_config('keystone_authtoken/certfile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/delay_auth_decision').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/enforce_token_bind').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/http_connect_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/http_request_max_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/include_service_catalog').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_magnum_config('keystone_authtoken/keyfile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_conn_get_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_dead_retry').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
@@ -98,20 +99,21 @@ describe 'magnum::keystone::authtoken' do
         is_expected.to contain_magnum_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_magnum_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
         is_expected.to contain_magnum_config('keystone_authtoken/project_name').with_value(params[:project_name])
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_user').with_value(params[:username])
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_password').with_value(params[:password]).with_secret(true)
-        is_expected.to contain_magnum_config('keystone_authtoken/admin_tenant_name').with_value(params[:project_name])
         is_expected.to contain_magnum_config('keystone_authtoken/user_domain_name').with_value(params[:user_domain_name])
         is_expected.to contain_magnum_config('keystone_authtoken/project_domain_name').with_value(params[:project_domain_name])
+        is_expected.to contain_magnum_config('keystone_authtoken/insecure').with_value(params[:insecure])
         is_expected.to contain_magnum_config('keystone_authtoken/auth_section').with_value(params[:auth_section])
         is_expected.to contain_magnum_config('keystone_authtoken/auth_type').with_value(params[:auth_type])
         is_expected.to contain_magnum_config('keystone_authtoken/auth_version').with_value(params[:auth_version])
         is_expected.to contain_magnum_config('keystone_authtoken/cache').with_value(params[:cache])
+        is_expected.to contain_magnum_config('keystone_authtoken/cafile').with_value(params[:cafile])
+        is_expected.to contain_magnum_config('keystone_authtoken/certfile').with_value(params[:certfile])
         is_expected.to contain_magnum_config('keystone_authtoken/delay_auth_decision').with_value(params[:delay_auth_decision])
         is_expected.to contain_magnum_config('keystone_authtoken/enforce_token_bind').with_value(params[:enforce_token_bind])
         is_expected.to contain_magnum_config('keystone_authtoken/http_connect_timeout').with_value(params[:http_connect_timeout])
         is_expected.to contain_magnum_config('keystone_authtoken/http_request_max_retries').with_value(params[:http_request_max_retries])
         is_expected.to contain_magnum_config('keystone_authtoken/include_service_catalog').with_value(params[:include_service_catalog])
+        is_expected.to contain_magnum_config('keystone_authtoken/keyfile').with_value(params[:keyfile])
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_conn_get_timeout').with_value(params[:memcache_pool_conn_get_timeout])
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_dead_retry').with_value(params[:memcache_pool_dead_retry])
         is_expected.to contain_magnum_config('keystone_authtoken/memcache_pool_maxsize').with_value(params[:memcache_pool_maxsize])
